pub fn read(config: &CacheConfig<'_>) -> Option<Cached>Expand description
Read the cached surface for the configured base URL, if there is a usable one.
pub fn read(config: &CacheConfig<'_>) -> Option<Cached>Read the cached surface for the configured base URL, if there is a usable one.