pub fn check(exposed: Table<'_>, unexposed: Table<'_>) -> Result<(), String>Expand description
The assertion form of report: Ok(()) when the tables and the contract
agree, and the rendered report as an error otherwise.
Returns a String error rather than this crate’s crate::Error because
its only caller is a test assertion, and the message is the whole value.